Struct EventConsumer

pub struct EventConsumer { /* private fields */ }
Available on Unix only.
EventConsumer This is a generic event consumer that can be used with eventfd or pipefd. It allows reading a value from the file descriptor to consume an event.

Examples

use std::os::fd::FromRawFd;
use std::os::unix::io::IntoRawFd;
use vmm_sys_util::event::EventConsumer;
let (reader, _) = std::io::pipe().expect("Failed to create pipe");
let consumer = unsafe { EventConsumer::from_raw_fd(reader.into_raw_fd()) };

Implementations

Source

impl EventConsumer

pub fn consume(&self) -> Result<(), Error>

Read a value from the EventConsumer.

pub fn try_clone(&self) -> Result<EventConsumer, Error>

Clone this EventConsumer.