pub struct EventNotifier { /* private fields */ }Available on Unix only.
EventNotifier This is a generic event notifier that can be used with eventfd or pipefd. It allows writing a value to the file descriptor to notify an event.
Examples
use std::os::fd::FromRawFd;
use std::os::unix::io::IntoRawFd;
use vmm_sys_util::event::EventNotifier;
let (_, writer) = std::io::pipe().expect("Failed to create pipe");
let notifier = unsafe { EventNotifier::from_raw_fd(writer.into_raw_fd()) };Implementations