[][src]Trait vmm_sys_util::file_traits::FileSetLen

pub trait FileSetLen {
    fn set_len(&self, len: u64) -> Result<()>;
}

A trait for setting the size of a file.

This is equivalent to std::fd::File::set_len method, but wrapped in a trait so that it can be implemented for other types.

Required methods

fn set_len(&self, len: u64) -> Result<()>

Set the size of this file.

This is the moral equivalent of ftruncate.

Arguments

  • len: the size to set for file.
Loading content...

Implementations on Foreign Types

impl FileSetLen for File[src]

Loading content...

Implementors

Loading content...