[][src]Struct vmm_sys_util::poll::PollContext

pub struct PollContext<T> { /* fields omitted */ }

Used to poll multiple objects that have file descriptors.

Example

let evt1 = EventFd::new(0).unwrap();
let evt2 = EventFd::new(0).unwrap();
evt2.write(1).unwrap();

let ctx: PollContext<u32> = PollContext::new().unwrap();
ctx.add(&evt1, 1).unwrap();
ctx.add(&evt2, 2).unwrap();

let pollevents: PollEvents<u32> = ctx.wait().unwrap();
let tokens: Vec<u32> = pollevents.iter_readable().map(|e| e.token()).collect();
assert_eq!(&tokens[..], &[2]);

Methods

impl<T: PollToken> PollContext<T>[src]

pub fn new() -> Result<PollContext<T>>[src]

Creates a new PollContext.

pub fn add(&self, fd: &dyn AsRawFd, token: T) -> Result<()>[src]

Adds the given fd to this context and associates the given token with the fd's readable events.

A fd can only be added once and does not need to be kept open. If the fd is dropped and there were no duplicated file descriptors (i.e. adding the same descriptor with a different FD number) added to this context, events will not be reported by wait anymore.

Arguments

  • fd: the target file descriptor to be added.
  • token: a PollToken implementation, used to be as u64 of libc::epoll_event structure.

pub fn add_fd_with_events(
    &self,
    fd: &dyn AsRawFd,
    events: WatchingEvents,
    token: T
) -> Result<()>
[src]

Adds the given fd to this context, watching for the specified events and associates the given 'token' with those events.

A fd can only be added once and does not need to be kept open. If the fd is dropped and there were no duplicated file descriptors (i.e. adding the same descriptor with a different FD number) added to this context, events will not be reported by wait anymore.

Arguments

  • fd: the target file descriptor to be added.
  • events: specifies the events to be watched.
  • token: a PollToken implementation, used to be as u64 of libc::epoll_event structure.

pub fn modify(
    &self,
    fd: &dyn AsRawFd,
    events: WatchingEvents,
    token: T
) -> Result<()>
[src]

Changes the setting associated with the given fd in this context.

If fd was previously added to this context, the watched events will be replaced with events and the token associated with it will be replaced with the given token.

Arguments

  • fd: the target file descriptor to be modified.
  • events: specifies the events to be watched.
  • token: a PollToken implementation, used to be as u64 of libc::epoll_event structure.

pub fn delete(&self, fd: &dyn AsRawFd) -> Result<()>[src]

Deletes the given fd from this context.

If an fd's token shows up in the list of hangup events, it should be removed using this method or by closing/dropping (if and only if the fd was never dup()'d/fork()'d) the fd. Failure to do so will cause the wait method to always return immediately, causing ~100% CPU load.

Arguments

  • fd: the target file descriptor to be removed.

pub fn wait(&self) -> Result<PollEvents<T>>[src]

Waits for any events to occur in FDs that were previously added to this context.

The events are level-triggered, meaning that if any events are unhandled (i.e. not reading for readable events and not closing for hungup events), subsequent calls to wait will return immediately. The consequence of not handling an event perpetually while calling wait is that the callers loop will degenerated to busy loop polling, pinning a CPU to ~100% usage.

Panics

Panics if the returned PollEvents structure is not dropped before subsequent wait calls.

pub fn wait_timeout(&self, timeout: Duration) -> Result<PollEvents<T>>[src]

Like wait except will only block for a maximum of the given timeout.

This may return earlier than timeout with zero events if the duration indicated exceeds system limits.

Arguments

  • timeout: specify the time that will block.