[−][src]Enum vmm_sys_util::signal::Error
The error cases enumeration for signal handling.
Variants
CreateSigset(Error)Couldn't create a sigset.
SignalAlreadyBlocked(c_int)The wrapped signal has already been blocked.
CompareBlockedSignals(Error)Failed to check if the requested signal is in the blocked set already.
BlockSignal(Error)The signal could not be blocked.
RetrieveSignalMask(c_int)The signal mask could not be retrieved.
UnblockSignal(Error)The signal could not be unblocked.
ClearWaitPending(Error)Failed to wait for given signal.
ClearGetPending(Error)Failed to get pending signals.
ClearCheckPending(Error)Failed to check if given signal is in the set of pending signals.