[−][src]Struct vmm_sys_util::tempdir::TempDir
Wrapper over a temporary directory.
The directory will be maintained for the lifetime of the TempDir object.
Methods
impl TempDir[src]
pub fn new<P: AsRef<OsStr>>(prefix: P) -> Result<TempDir>[src]
Creates a new temporary directory with prefix.
The directory will be removed when the object goes out of scope.
Examples
let t = TempDir::new("/tmp/testdir").unwrap();
pub fn remove(&self) -> Result<()>[src]
Removes the temporary directory.
Calling this is optional as when a TempDir object goes out of scope,
the directory will be removed.
Calling remove explicitly allows for better error handling.
Errors
This function can only be called once per object. An error is returned otherwise.
Examples
let temp_dir = TempDir::new("/tmp/testdir").unwrap(); temp_dir.remove().unwrap();
pub fn as_path(&self) -> &Path[src]
Returns the path to the tempdir.
Examples
let temp_dir = TempDir::new("/tmp/testdir").unwrap(); assert!(temp_dir.as_path().exists());