[−][src]Struct vmm_sys_util::tempfile::TempFile
Wrapper for working with temporary files.
The file will be maintained for the lifetime of the TempFile object.
Methods
impl TempFile[src]
pub fn new_with_prefix<P: AsRef<OsStr>>(prefix: P) -> Result<TempFile>[src]
Creates the TempFile using a prefix.
Arguments
prefix: The path and filename where to creat the temporary file. Six
random alphanumeric characters will be added to the end of this to form
the filename.
pub fn new_in(path: &Path) -> Result<Self>[src]
Creates the TempFile inside a specific location.
Arguments
path: The path where to create a temporary file with a filename formed from
six random alphanumeric characters.
pub fn new() -> Result<Self>[src]
Creates the TempFile.
Creates a temporary file inside $TMPDIR if set, otherwise inside /tmp.
The filename will consist from six random alphanumeric characters.
pub fn remove(&mut self) -> Result<()>[src]
Removes the temporary file.
Calling this is optional as dropping a TempFile object will also
remove the file. Calling remove explicitly allows for better error
handling.
pub fn as_path(&self) -> &Path[src]
Returns the path to the tempfile if it is currently valid
pub fn as_file(&self) -> &File[src]
Returns a reference to the File