[−][src]Crate vmm_sys_util
Collection of modules that provides helpers and utilities used by multiple rust-vmm components.
Modules
| aio | Safe wrapper over |
| errno | Structures, helpers, and type definitions for working with
|
| eventfd | Structure and wrapper functions for working with
|
| fallocate | Enum and function for dealing with an allocated disk space
by |
| fam | Trait and wrapper for working with C defined FAM structures. |
| file_traits | Traits for handling file synchronization and length. |
| ioctl | Macros and functions for working with
|
| poll | Traits and structures for working with
|
| rand | Miscellaneous functions related to getting (pseudo) random numbers and strings. |
| seek_hole | Traits and implementations over lseek64. |
| signal | Enums, traits and functions for working with
|
| sock_ctrl_msg | Wrapper for sending and receiving messages with file descriptors on sockets that accept control messages (e.g. Unix domain sockets). |
| tempdir | Structure for handling temporary directories. |
| tempfile | Struct for handling temporary files as well as any cleanup required. |
| terminal | Trait for working with |
| timerfd | Structure and functions for working with
|
| write_zeroes | Traits for replacing a range with a hole and writing zeroes in a file. |
Macros
| generate_fam_struct_impl | Generate |
| ioctl_expr | Expression that calculates an ioctl number. |
| ioctl_io_nr | Declare an ioctl that transfers no data. |
| ioctl_ioc_nr | Declare a function that returns an ioctl number. |
| ioctl_ior_nr | Declare an ioctl that reads data. |
| ioctl_iow_nr | Declare an ioctl that writes data. |
| ioctl_iowr_nr | Declare an ioctl that reads and writes data. |