[−][src]Struct vmm_sys_util::errno::Error
Wrapper over errno.
The error number is an integer number set by system calls and some libc functions in case of error.
Methods
impl Error[src]
pub fn new(errno: i32) -> Error[src]
Creates a new error from the given error number.
Arguments
errno: error number used for creating theError.
Examples
extern crate vmm_sys_util; use vmm_sys_util::errno::Error; let err = Error::new(libc::EBADFD);
pub fn last() -> Error[src]
Returns the last occurred errno wrapped in an Error.
Calling Error::last() is the equivalent of using
errno in C/C++.
The result of this function only has meaning after a libc call or syscall
where errno was set.
Examples
extern crate vmm_sys_util; use vmm_sys_util::errno::Error; // Writing to an invalid file returns the error number EBADF. let mut file = unsafe { File::from_raw_fd(-1) }; let _ = file.write(b"test"); // Retrieve the error number of the previous operation using `Error::last()`: let write_err = Error::last(); assert_eq!(write_err, Error::new(libc::EBADF));
pub fn errno(self) -> i32[src]
Returns the raw integer value (errno) corresponding to this Error.
Examples
extern crate vmm_sys_util; use vmm_sys_util::errno::Error; let err = Error::new(13); assert_eq!(err.errno(), 13);