[−][src]Trait vmm_sys_util::file_traits::FileSetLen
A trait for setting the size of a file.
This is equivalent to
std::fd::File::set_len
method, but wrapped in a trait so that it can be implemented for other types.
A trait for setting the size of a file.
This is equivalent to
std::fd::File::set_len
method, but wrapped in a trait so that it can be implemented for other types.
impl FileSetLen for File[src]