[−][src]Struct vmm_sys_util::poll::PollEvent
An event returned by PollContext::wait.
Methods
impl<'a, T: PollToken> PollEvent<'a, T>[src]
pub fn token(&self) -> T[src]
Gets the token associated in
PollContext::add with this event.
pub fn readable(&self) -> bool[src]
Checks if the event is readable.
True if the fd associated with this token in
PollContext::add is readable.
pub fn hungup(&self) -> bool[src]
Checks if the event has been hangup on.
True if the fd associated with this token in
PollContext::add has been hungup on.